==> haskell-pager-0.1.1.0-211-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-EloYtPCG6QYBVfMNx16tVL
key:                  pager-0.1.1.0-EloYtPCG6QYBVfMNx16tVL
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  c30dbe59c81ad371165cfeece6b75d40
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pager-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-EloYtPCG6QYBVfMNx16tVL
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6 directory-1.3.8.5
    process-1.6.19.0 resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs
    safe-0.3.21-7oQO4KcgDWt1YhK3ifcAwa terminfo-0.4.1.6 text-2.0.2
    transformers-0.6.1.0 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pager-0.1.1.0-213-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-8hMLiAb1ZyP8DBGwwXK8zQ
key:                  pager-0.1.1.0-8hMLiAb1ZyP8DBGwwXK8zQ
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  808c2d9a66a9914a87005989866e6366
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pager-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-8hMLiAb1ZyP8DBGwwXK8zQ
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy
    conduit-extra-1.3.8-GHF5wYhQp30HUaLAtCbs0G directory-1.3.8.5
    process-1.6.19.0 resourcet-1.2.6-JtO0n9rtgTt543EMYn7K77
    safe-0.3.21-KkG5O6k2axl5FoNYEbOYS8 terminfo-0.4.1.6 text-2.0.2
    transformers-0.6.1.0 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
